#[non_exhaustive]pub struct CallChainEntry {
pub symbol: String,
pub file: String,
pub line: usize,
}Expand description
Single entry in a call chain (depth-1 direct caller or callee).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.symbol: Stringfile: Stringline: usizeTrait Implementations
Sourceimpl Clone for CallChainEntry
impl Clone for CallChainEntry
Sourcefn clone(&self) -> CallChainEntry
fn clone(&self) -> CallChainEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CallChainEntry
impl Debug for CallChainEntry
Sourceimpl<'de> Deserialize<'de> for CallChainEntry
impl<'de> Deserialize<'de> for CallChainEntry
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CallChainEntry, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CallChainEntry, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CallChainEntry
impl Hash for CallChainEntry
Sourceimpl JsonSchema for CallChainEntry
impl JsonSchema for CallChainEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CallChainEntry
impl PartialEq for CallChainEntry
Sourcefn eq(&self, other: &CallChainEntry) -> bool
fn eq(&self, other: &CallChainEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CallChainEntry
impl Serialize for CallChainEntry
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for CallChainEntry
impl StructuralPartialEq for CallChainEntry