pub fn path_file_ext(path: &str) -> Option<&'static str>Expand description
Returns the lowercased file extension of path as a &'static str.
- Returns
Some(ext)for extensions recognized bylanguage_for_extension(e.g."rs"). - Returns
Some("other")for paths that have an extension but it is not in the known set. - Returns
Nonefor paths with no extension or an empty extension.